"""
This file is part of the vaccination.py.

(c) 2021 Temuri Takalandze <me@abgeo.dev>

For the full copyright and license information, please view the LICENSE
file that was distributed with this source code.
"""

__project__ = "vaccination"
__author__ = "Temuri Takalandze"
__copyright__ = "(c) 2021 Temuri Takalandze"
__email__ = "me@abgeo.dev"
__credits__ = ["Temuri Takalandze"]
__license__ = "MIT"
__version__ = "1.2.0"
__status__ = "Stable"
